@@ -2,7 +2,7 @@ package PICA::Data;
 use strict;
 use warnings;
 
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(pica_parser pica_writer pica_path pica_xml_struct
@@ -221,12 +221,15 @@ PICA::Data - PICA record processing
 
 =begin markdown 
 
-[![Build Status](https://travis-ci.org/gbv/PICA-Data.png)](https://travis-ci.org/gbv/PICA-Data)
-[![Coverage Status](https://coveralls.io/repos/gbv/PICA-Data/badge.png)](https://coveralls.io/r/gbv/PICA-Data)
+[![Unix build Status](https://travis-ci.org/gbv/PICA-Data.png)](https://travis-ci.org/gbv/PICA-Data)
+[![Windows build status](https://ci.appveyor.com/api/projects/status/5qjak74x7mjy7ne6?svg=true)](https://ci.appveyor.com/project/nichtich/pica-data)
+[![Coverage Status](https://coveralls.io/repos/gbv/PICA-Data/badge.svg)](https://coveralls.io/r/gbv/PICA-Data)
 [![Kwalitee Score](http://cpants.cpanauthors.org/dist/PICA-Data.png)](http://cpants.cpanauthors.org/dist/PICA-Data)
 
 =end markdown
 
+=encoding UTF-8
+
 =head1 SYNOPSIS
 
     use PICA::Data ':all';
@@ -278,8 +281,8 @@ PICA::Data - PICA record processing
 
 =head1 DESCRIPTION
 
-PICA::Data provides methods, classes, and functions to process PICA+ records
-in Perl.
+PICA::Data provides methods, classes, and functions to process
+L<PICA+ records|http://format.gbv.de/pica> in Perl.
 
 PICA+ is the internal data format of the Local Library System (LBS) and the
 Central Library System (CBS) of OCLC, formerly PICA. Similar library formats
@@ -461,7 +464,7 @@ record objects:
 
 Johann Rolschewski, C<< <jorol@cpan.org> >>
 
-Jakob Voss C<< <voss@gbv.de> >>
+Jakob Voß C<< <voss@gbv.de> >>
 
 Carsten Klee C<< <klee@cpan.org> >>
 
