@@ -2,7 +2,7 @@ package PICA::Writer::XML;
 use strict;
 use warnings;
 
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 
 use Scalar::Util qw(reftype);
 use XML::Writer;
@@ -23,6 +23,7 @@ sub write_record {
     $record = $record->{record} if reftype $record eq 'HASH';
 
     my $writer = $self->{writer};
+    my $schema = $self->{schema} // { field => { } };
 
     my $i = 0;
     my $pica_sort = sub {
@@ -35,15 +36,35 @@ sub write_record {
     @$record = map $_->[1], sort { $a->[0] cmp $b->[0] } map { $pica_sort->($_) } @$record;
     $writer->startTag('record');
     foreach my $field (@$record) {
+        my $id = $field->[0];
+        my @attr = (tag => $field->[0]);
         if ( defined $field->[1] && $field->[1] ne '') {
-            $writer->startTag('datafield', tag => $field->[0], occurrence => $field->[1] );
+            push @attr, occurrence => $field->[1];
+            $id = "$id/".$field->[1];
         }
-        else {
-            $writer->startTag('datafield', tag => $field->[0]);
+        my $fielddef = $schema->{fields}{$id};
+        my $sfdef;
+        if ($fielddef) {
+            foreach (qw(label url pica3)) {
+                if (defined $fielddef->{$_}) {
+                    push @attr, $_ => $fielddef->{$_};
+                }
+            }
+            $sfdef = $fielddef->{subfields};
         }
+        $writer->startTag('datafield', @attr );
         for (my $i=2; $i<scalar @$field; $i+=2) {
+            my $code = $field->[$i];
             my $value = $field->[$i+1];
-            $writer->dataElement('subfield', $value, code => $field->[$i]);
+            my @attr = (code => $code);
+            if ($sfdef && $sfdef->{$code}) {
+                foreach (qw(label url pica3)) {
+                    if (defined $sfdef->{$code}{$_}) {
+                        push @attr, $_ => $sfdef->{$code}{$_};
+                    }
+                }
+            }
+            $writer->dataElement('subfield', $value, @attr);
         } 
         $writer->endTag('datafield');
     }
@@ -65,7 +86,11 @@ PICA::Writer::XML - PICA+ XML format serializer
 
 =head2 DESCRIPTION
 
-See L<PICA::Writer::Base> for synopsis and details.
+See L<PICA::Writer::Base> for synopsis and details. In addition a
+L<PICA::Schema> can be provided to include schema information in the XML
+records for human-readable documentation:
+
+    my $writer = PICA::Writer::XML->new( fh => $file, schema => $schema );
 
 The counterpart of this module is L<PICA::Parser::XML>.
 
